<?php

declare(strict_types=1);

namespace mirzaev\unchainer\models\telegram;

// Files of the project
use mirzaev\unchainer\models\core,
	mirzaev\unchainer\models\account,
	mirzaev\unchainer\models\telegram\selections,
	mirzaev\unchainer\models\enumerations\language;

// Framework for Telegram
use Zanzara\Context as context,
	Zanzara\Telegram\Type\Message as message,
	Zanzara\Telegram\Type\Input\InputFile as file_input;

// Baza database
use mirzaev\baza\record;

/**
 * Telegram commands
 *
 * @package mirzaev\unchainer\models\telegram
 *
 * @license http://www.wtfpl.net/ Do What The Fuck You Want To Public License
 * @author Arsen Mirzaev Tatyano-Muradovich <arsen@mirzaev.sexy>
 */
final class commands extends core
{
	/**
	 * Menu
	 *
	 * Responce for the commands: "/start", '/menu'
	 *
	 * @param context $context Request data from Telegram
	 *
	 * @return void
	 */
	public static function menu(context $context): void
	{
		// Initializing the account
		$account = $context->get('account');

		if ($account instanceof record) {
			// Initialized the account

			// Initializing localization 
			$localization = $context->get('localization');

			if ($localization) {
				// Initialized localization

				// Initializing the title
				$title = '📋 *' . $localization['menu_title'] . '*';

				// Initializing accounts
				/* $accounts = '*' . $localization['menu_accounts'] . '* ' . (new account->database->count() ?? 0); */
				$accounts = '*' . $localization['menu_accounts'] . '* ' . ((new account)->database->count() ?? 0);

				// Initializing requests
				$requests = '*' . $localization['menu_requests'] . '* ' . 0 . ' 🔗';

				// Initializing foundation
				$foundation = '*' . $localization['menu_foundation'] . '* ' . 0 . ' ⭐️';

				// Initializing day statistic
				$day = '*' . $localization['menu_statistic_day'] . '* ' . 0 . ' ⛓️‍💥' . ', ' . 0 . ' ⭐️';

				// Initializing week statistic
				$week = '*' . $localization['menu_statistic_week'] . '* ' . 0 . ' ⛓️‍💥' . ', ' . 0 . ' ⭐️';

				// Initializing month statistic
				$month = '*' . $localization['menu_statistic_month'] . '* ' . 0 . ' ⛓️‍💥' . ', ' . 0 . ' ⭐️';

				// Initializing year statistic
				$year = '*' . $localization['menu_statistic_year'] . '* ' . 0 . ' ⛓️‍💥' . ', ' . 0 . ' ⭐️';

				// Initializing total statistic
				$total = '*' . $localization['menu_statistic_total'] . '* ' . 0 . ' ⛓️‍💥' . ', ' . 0 . ' ⭐️';

				// Sending the message
				$context->sendMessage(
					<<<TXT
					$title

					$requests
					$accounts
					$foundation

					$day
					$week
					$month
					$year
					$total
					TXT,
					[
						'reply_markup' => [
							'inline_keyboard' => [
								[
									[
										'text' => '⛓️‍💥 ' . $localization['menu_button_request'],
										'callback_data' => 'request'
									],
									[
										'text' => '🔎 ' . $localization['menu_button_search'],
										'callback_data' => 'search'
									]
								],
								[
									[
										'text' => '📕 ' . $localization['menu_button_account'],
										'callback_data' => 'account'
									]
								],
								/* [
									[
										'text' => '❤️‍🩹 ' . $localization['menu_button_unchainers'],
										'callback_data' => 'unchainers'
									]
								] */
							],
							'disable_notification' => true,
							'remove_keyboard' => true
						],
					]

				)
					->then(function (message $message) use ($context) {
						// Sended the message


					});
			} else {
				// Not initialized localization

				// Sending the message
				$context->sendMessage('⚠️ *Failed to initialize localization*')
					->then(function (message $message) use ($context) {
						// Ending the conversation process
						$context->endConversation();
					});
			}
		} else {
			// Not initialized the account

			// Sending the message
			$context->sendMessage('⚠️ *Failed to initialize your Telegram account*')
				->then(function (message $message) use ($context) {
					// Ending the conversation process
					$context->endConversation();
				});
		}
	}

	/**
	 * Distributions
	 *
	 * Responce for the command: "/distributions"
	 * 
	 * Sends the distributions menu
	 *
	 * @param context $context Request data from Telegram
	 *
	 * @return void
	 */
	public static function distributions(context $context): void
	{
		// Initializing the account
		$account = $context->get('account');

		if ($account instanceof record) {
			// Initialized the account

			// Initializing language 
			$language = $context->get('language');

			if ($language instanceof language) {
				// Initialized language

				// Initializing localization 
				$localization = $context->get('localization');

				if ($localization) {
					// Initialized localization

					// Initializing the message title
					$title = '🏘 *' . $localization['distributions_title'] . '*';

					// Initializing the message description
					$description = $localization['distributions_description'];

					// Initializing the distribution model
					$model = new distribution;

					// Initializing the message "registered" row
					$registered = '*' . $localization['distributions_registered'] . ':* ' . $model->database->count();

					// Sending the message
					$context->sendMessage(
						<<<TXT
						$title
						
						$registered

						$description
						TXT,
						[
							'reply_markup' => [
								'inline_keyboard' => [
									[
										[
											'text' => '📋 ' . $localization['distributions_button_register'],
											'callback_data' => 'distribution_registration_start'
										],
										[
											'text' => '🔎 ' . $localization['distributions_button_search'],
											'callback_data' => 'distribution_search_start'
										]
									]
								],
								'disable_notification' => true,
								'remove_keyboard' => true
							],
						]
					);
				} else {
					// Not initialized localization

					// Sending the message
					$context->sendMessage('⚠️ *Failed to initialize localization*')
						->then(function (message $message) use ($context) {
							// Ending the conversation process
							$context->endConversation();
						});
				}
			} else {
				// Not initialized language

				// Sending the message
				$context->sendMessage('⚠️ *Failed to initialize language*')
					->then(function (message $message) use ($context) {
						// Ending the conversation process
						$context->endConversation();
					});
			}
		} else {
			// Not initialized the account

			// Sending the message
			$context->sendMessage('⚠️ *Failed to initialize your Telegram account*')
				->then(function (message $message) use ($context) {
					// Ending the conversation process
					$context->endConversation();
				});
		}
	}

	/**
	 * Language
	 *
	 * Responce for the command: "/language"
	 * 
	 * Send the language selection menu
	 *
	 * @param context $context Request data from Telegram
	 *
	 * @return void
	 */
	public static function language(context $context): void
	{
		// Initializing the account
		$account = $context->get('account');

		if ($account instanceof record) {
			// Initialized the account

			// Initializing language 
			$language = $context->get('language');

			if ($language instanceof language) {
				// Initialized language

				// Initializing localization 
				$localization = $context->get('localization');

				if ($localization) {
					// Initialized localization

					// Sending the language selection
					selections::language(
						context: $context,
						prefix: 'settings_language_',
						title: '🌏 *' . $localization['settings_select_language_title'] . '*',
						description: '🌏 *' . $localization['settings_select_language_description'] . '*'
					);
				} else {
					// Not initialized localization

					// Sending the message
					$context->sendMessage('⚠️ *Failed to initialize localization*')
						->then(function (message $message) use ($context) {
							// Ending the conversation process
							$context->endConversation();
						});
				}
			} else {
				// Not initialized language

				// Sending the message
				$context->sendMessage('⚠️ *Failed to initialize language*')
					->then(function (message $message) use ($context) {
						// Ending the conversation process
						$context->endConversation();
					});
			}
		} else {
			// Not initialized the account

			// Sending the message
			$context->sendMessage('⚠️ *Failed to initialize your Telegram account*')
				->then(function (message $message) use ($context) {
					// Ending the conversation process
					$context->endConversation();
				});
		}
	}

	/**
	 * Author
	 *
	 * Responce for the command: "/author"
	 *
	 * Sends information about author and menu
	 *
	 * @param context $context Request data from Telegram
	 *
	 * @return void
	 */
	public static function author(context $context): void
	{
		// Initializing the account
		$account = $context->get('account');

		if ($account instanceof record) {
			// Initialized the account

			// Initializing localization 
			$localization = $context->get('localization');

			if ($localization) {
				// Initialized localization

				// Sending the message
				$context->sendPhoto(
					new file_input(STORAGE . DIRECTORY_SEPARATOR . 'images' . DIRECTORY_SEPARATOR . 'mushroom.jpg'),
					[
						'caption' => $localization['why_so_shroomious'],
						'disable_notification' => true
					]
				);
			} else {
				// Not initialized localization

				// Sending the message
				$context->sendMessage('⚠️ *Failed to initialize localization*')
					->then(function (message $message) use ($context) {
						// Ending the conversation process
						$context->endConversation();
					});
			}
		} else {
			// Not initialized the account

			// Sending the message
			$context->sendMessage('⚠️ *Failed to initialize your Telegram account*')
				->then(function (message $message) use ($context) {
					// Ending the conversation process
					$context->endConversation();
				});
		}
	}
}
